let foo;
{
    let foo__2;
}
